# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/notification/v1/discussion_notifications.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/notification/v1/discussion_notifications.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import discussion_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_discussion__pb2
from .....olvid.daemon.datatypes.v1 import settings_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_settings__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;olvid/daemon/notification/v1/discussion_notifications.proto\x12\x1colvid.daemon.notification.v1\x1a*olvid/daemon/datatypes/v1/discussion.proto\x1a(olvid/daemon/datatypes/v1/settings.proto\"\xa0\x01\n$SubscribeToDiscussionNewNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12H\n\x06\x66ilter\x18\x02 \x01(\x0b\x32+.olvid.daemon.datatypes.v1.DiscussionFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"b\n\x19\x44iscussionNewNotification\x12\x45\n\ndiscussion\x18\x01 \x01(\x0b\x32%.olvid.daemon.datatypes.v1.DiscussionR\ndiscussion\"\xca\x01\n\'SubscribeToDiscussionLockedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12H\n\x06\x66ilter\x18\x02 \x01(\x0b\x32+.olvid.daemon.datatypes.v1.DiscussionFilterH\x01R\x06\x66ilter\x88\x01\x01\x12%\n\x0e\x64iscussion_ids\x18\x03 \x03(\x04R\rdiscussionIdsB\x08\n\x06_countB\t\n\x07_filter\"e\n\x1c\x44iscussionLockedNotification\x12\x45\n\ndiscussion\x18\x01 \x01(\x0b\x32%.olvid.daemon.datatypes.v1.DiscussionR\ndiscussion\"\xd0\x01\n-SubscribeToDiscussionTitleUpdatedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12H\n\x06\x66ilter\x18\x02 \x01(\x0b\x32+.olvid.daemon.datatypes.v1.DiscussionFilterH\x01R\x06\x66ilter\x88\x01\x01\x12%\n\x0e\x64iscussion_ids\x18\x03 \x03(\x04R\rdiscussionIdsB\x08\n\x06_countB\t\n\x07_filter\"\x92\x01\n\"DiscussionTitleUpdatedNotification\x12\x45\n\ndiscussion\x18\x01 \x01(\x0b\x32%.olvid.daemon.datatypes.v1.DiscussionR\ndiscussion\x12%\n\x0eprevious_title\x18\x02 \x01(\tR\rpreviousTitle\"\xd3\x01\n0SubscribeToDiscussionSettingsUpdatedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12H\n\x06\x66ilter\x18\x02 \x01(\x0b\x32+.olvid.daemon.datatypes.v1.DiscussionFilterH\x01R\x06\x66ilter\x88\x01\x01\x12%\n\x0e\x64iscussion_ids\x18\x03 \x03(\x04R\rdiscussionIdsB\x08\n\x06_countB\t\n\x07_filter\"\x9c\x02\n%DiscussionSettingsUpdatedNotification\x12\x45\n\ndiscussion\x18\x01 \x01(\x0b\x32%.olvid.daemon.datatypes.v1.DiscussionR\ndiscussion\x12P\n\x0cnew_settings\x18\x02 \x01(\x0b\x32-.olvid.daemon.datatypes.v1.DiscussionSettingsR\x0bnewSettings\x12Z\n\x11previous_settings\x18\x03 \x01(\x0b\x32-.olvid.daemon.datatypes.v1.DiscussionSettingsR\x10previousSettingsB\xe4\x01\n com.olvid.daemon.notification.v1B\x1c\x44iscussionNotificationsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODN\xaa\x02\x1cOlvid.Daemon.Notification.V1\xca\x02\x1cOlvid\\Daemon\\Notification\\V1\xe2\x02(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\xea\x02\x1fOlvid::Daemon::Notification::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.notification.v1.discussion_notifications_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.olvid.daemon.notification.v1B\034DiscussionNotificationsProtoP\001Z\017olvid.io/daemon\242\002\003ODN\252\002\034Olvid.Daemon.Notification.V1\312\002\034Olvid\\Daemon\\Notification\\V1\342\002(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\352\002\037Olvid::Daemon::Notification::V1'
  _globals['_SUBSCRIBETODISCUSSIONNEWNOTIFICATION']._serialized_start=180
  _globals['_SUBSCRIBETODISCUSSIONNEWNOTIFICATION']._serialized_end=340
  _globals['_DISCUSSIONNEWNOTIFICATION']._serialized_start=342
  _globals['_DISCUSSIONNEWNOTIFICATION']._serialized_end=440
  _globals['_SUBSCRIBETODISCUSSIONLOCKEDNOTIFICATION']._serialized_start=443
  _globals['_SUBSCRIBETODISCUSSIONLOCKEDNOTIFICATION']._serialized_end=645
  _globals['_DISCUSSIONLOCKEDNOTIFICATION']._serialized_start=647
  _globals['_DISCUSSIONLOCKEDNOTIFICATION']._serialized_end=748
  _globals['_SUBSCRIBETODISCUSSIONTITLEUPDATEDNOTIFICATION']._serialized_start=751
  _globals['_SUBSCRIBETODISCUSSIONTITLEUPDATEDNOTIFICATION']._serialized_end=959
  _globals['_DISCUSSIONTITLEUPDATEDNOTIFICATION']._serialized_start=962
  _globals['_DISCUSSIONTITLEUPDATEDNOTIFICATION']._serialized_end=1108
  _globals['_SUBSCRIBETODISCUSSIONSETTINGSUPDATEDNOTIFICATION']._serialized_start=1111
  _globals['_SUBSCRIBETODISCUSSIONSETTINGSUPDATEDNOTIFICATION']._serialized_end=1322
  _globals['_DISCUSSIONSETTINGSUPDATEDNOTIFICATION']._serialized_start=1325
  _globals['_DISCUSSIONSETTINGSUPDATEDNOTIFICATION']._serialized_end=1609
# @@protoc_insertion_point(module_scope)



from ..interactive_tree import interactive_tree

from ..tools.cli_tools import *

#####
# call
#####
@interactive_tree.group("call", short_help="Manage your calls")
def call_tree():
	pass

#####
# call start
#####
@call_tree.command("start", short_help="start a new call in a discussion")
@click.option("-d", "--discussion", "discussion_id", type=int, default=None, help="Use passed id as discussion id")
@click.argument("contact_ids", nargs=-1, type=click.INT)
async def call_start(contact_ids: list[int], discussion_id: int):
	if contact_ids:
		call_identifier = await ClientSingleton.get_client().call_start_custom_call(contact_ids=contact_ids, discussion_id=discussion_id)
	else:
		call_identifier = await ClientSingleton.get_client().call_start_discussion_call(discussion_id=discussion_id)
	print_success_message(f"Call started: {call_identifier}", call_identifier)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/command/v1/group_commands.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/command/v1/group_commands.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import group_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_group__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,olvid/daemon/command/v1/group_commands.proto\x12\x17olvid.daemon.command.v1\x1a%olvid/daemon/datatypes/v1/group.proto\"b\n\x10GroupListRequest\x12\x43\n\x06\x66ilter\x18\x01 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupFilterH\x00R\x06\x66ilter\x88\x01\x01\x42\t\n\x07_filter\"M\n\x11GroupListResponse\x12\x38\n\x06groups\x18\x01 \x03(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x06groups\",\n\x0fGroupGetRequest\x12\x19\n\x08group_id\x18\x01 \x01(\x04R\x07groupId\"J\n\x10GroupGetResponse\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\";\n\x1eGroupGetBytesIdentifierRequest\x12\x19\n\x08group_id\x18\x01 \x01(\x04R\x07groupId\"A\n\x1fGroupGetBytesIdentifierResponse\x12\x1e\n\nidentifier\x18\x01 \x01(\x0cR\nidentifier\"\xa3\x01\n\x1cGroupNewStandardGroupRequest\x12\x17\n\x04name\x18\x01 \x01(\tH\x00R\x04name\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12*\n\x11\x61\x64min_contact_ids\x18\x03 \x03(\x04R\x0f\x61\x64minContactIdsB\x07\n\x05_nameB\x0e\n\x0c_description\"W\n\x1dGroupNewStandardGroupResponse\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\"\xc6\x01\n\x1eGroupNewControlledGroupRequest\x12\x17\n\x04name\x18\x01 \x01(\tH\x00R\x04name\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12*\n\x11\x61\x64min_contact_ids\x18\x03 \x03(\x04R\x0f\x61\x64minContactIds\x12\x1f\n\x0b\x63ontact_ids\x18\x04 \x03(\x04R\ncontactIdsB\x07\n\x05_nameB\x0e\n\x0c_description\"Y\n\x1fGroupNewControlledGroupResponse\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\"\xc4\x01\n\x1cGroupNewReadOnlyGroupRequest\x12\x17\n\x04name\x18\x01 \x01(\tH\x00R\x04name\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12*\n\x11\x61\x64min_contact_ids\x18\x03 \x03(\x04R\x0f\x61\x64minContactIds\x12\x1f\n\x0b\x63ontact_ids\x18\x04 \x03(\x04R\ncontactIdsB\x07\n\x05_nameB\x0e\n\x0c_description\"W\n\x1dGroupNewReadOnlyGroupResponse\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\"\xc8\x02\n\x1cGroupNewAdvancedGroupRequest\x12\x17\n\x04name\x18\x01 \x01(\tH\x00R\x04name\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12r\n\x16\x61\x64vanced_configuration\x18\x03 \x01(\x0b\x32\x36.olvid.daemon.datatypes.v1.Group.AdvancedConfigurationH\x02R\x15\x61\x64vancedConfiguration\x88\x01\x01\x12@\n\x07members\x18\x04 \x03(\x0b\x32&.olvid.daemon.datatypes.v1.GroupMemberR\x07membersB\x07\n\x05_nameB\x0e\n\x0c_descriptionB\x19\n\x17_advanced_configuration\"W\n\x1dGroupNewAdvancedGroupResponse\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\"0\n\x13GroupDisbandRequest\x12\x19\n\x08group_id\x18\x01 \x01(\x04R\x07groupId\"N\n\x14GroupDisbandResponse\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\".\n\x11GroupLeaveRequest\x12\x19\n\x08group_id\x18\x01 \x01(\x04R\x07groupId\"L\n\x12GroupLeaveResponse\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\"L\n\x12GroupUpdateRequest\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\"M\n\x13GroupUpdateResponse\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\"3\n\x16GroupUnsetPhotoRequest\x12\x19\n\x08group_id\x18\x01 \x01(\x04R\x07groupId\"Q\n\x17GroupUnsetPhotoResponse\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\"r\n\x1cGroupSetPhotoRequestMetadata\x12\x19\n\x08group_id\x18\x01 \x01(\x04R\x07groupId\x12\x1a\n\x08\x66ilename\x18\x02 \x01(\tR\x08\x66ilename\x12\x1b\n\tfile_size\x18\x03 \x01(\x04R\x08\x66ileSize\"\x92\x01\n\x14GroupSetPhotoRequest\x12S\n\x08metadata\x18\x01 \x01(\x0b\x32\x35.olvid.daemon.command.v1.GroupSetPhotoRequestMetadataH\x00R\x08metadata\x12\x1a\n\x07payload\x18\x02 \x01(\x0cH\x00R\x07payloadB\t\n\x07request\"O\n\x15GroupSetPhotoResponse\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\"6\n\x19GroupDownloadPhotoRequest\x12\x19\n\x08group_id\x18\x01 \x01(\x04R\x07groupId\"2\n\x1aGroupDownloadPhotoResponse\x12\x14\n\x05photo\x18\x01 \x01(\x0cR\x05photoB\xc1\x01\n\x1b\x63om.olvid.daemon.command.v1B\x12GroupCommandsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODC\xaa\x02\x17Olvid.Daemon.Command.V1\xca\x02\x17Olvid\\Daemon\\Command\\V1\xe2\x02#Olvid\\Daemon\\Command\\V1\\GPBMetadata\xea\x02\x1aOlvid::Daemon::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.command.v1.group_commands_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.olvid.daemon.command.v1B\022GroupCommandsProtoP\001Z\017olvid.io/daemon\242\002\003ODC\252\002\027Olvid.Daemon.Command.V1\312\002\027Olvid\\Daemon\\Command\\V1\342\002#Olvid\\Daemon\\Command\\V1\\GPBMetadata\352\002\032Olvid::Daemon::Command::V1'
  _globals['_GROUPLISTREQUEST']._serialized_start=112
  _globals['_GROUPLISTREQUEST']._serialized_end=210
  _globals['_GROUPLISTRESPONSE']._serialized_start=212
  _globals['_GROUPLISTRESPONSE']._serialized_end=289
  _globals['_GROUPGETREQUEST']._serialized_start=291
  _globals['_GROUPGETREQUEST']._serialized_end=335
  _globals['_GROUPGETRESPONSE']._serialized_start=337
  _globals['_GROUPGETRESPONSE']._serialized_end=411
  _globals['_GROUPGETBYTESIDENTIFIERREQUEST']._serialized_start=413
  _globals['_GROUPGETBYTESIDENTIFIERREQUEST']._serialized_end=472
  _globals['_GROUPGETBYTESIDENTIFIERRESPONSE']._serialized_start=474
  _globals['_GROUPGETBYTESIDENTIFIERRESPONSE']._serialized_end=539
  _globals['_GROUPNEWSTANDARDGROUPREQUEST']._serialized_start=542
  _globals['_GROUPNEWSTANDARDGROUPREQUEST']._serialized_end=705
  _globals['_GROUPNEWSTANDARDGROUPRESPONSE']._serialized_start=707
  _globals['_GROUPNEWSTANDARDGROUPRESPONSE']._serialized_end=794
  _globals['_GROUPNEWCONTROLLEDGROUPREQUEST']._serialized_start=797
  _globals['_GROUPNEWCONTROLLEDGROUPREQUEST']._serialized_end=995
  _globals['_GROUPNEWCONTROLLEDGROUPRESPONSE']._serialized_start=997
  _globals['_GROUPNEWCONTROLLEDGROUPRESPONSE']._serialized_end=1086
  _globals['_GROUPNEWREADONLYGROUPREQUEST']._serialized_start=1089
  _globals['_GROUPNEWREADONLYGROUPREQUEST']._serialized_end=1285
  _globals['_GROUPNEWREADONLYGROUPRESPONSE']._serialized_start=1287
  _globals['_GROUPNEWREADONLYGROUPRESPONSE']._serialized_end=1374
  _globals['_GROUPNEWADVANCEDGROUPREQUEST']._serialized_start=1377
  _globals['_GROUPNEWADVANCEDGROUPREQUEST']._serialized_end=1705
  _globals['_GROUPNEWADVANCEDGROUPRESPONSE']._serialized_start=1707
  _globals['_GROUPNEWADVANCEDGROUPRESPONSE']._serialized_end=1794
  _globals['_GROUPDISBANDREQUEST']._serialized_start=1796
  _globals['_GROUPDISBANDREQUEST']._serialized_end=1844
  _globals['_GROUPDISBANDRESPONSE']._serialized_start=1846
  _globals['_GROUPDISBANDRESPONSE']._serialized_end=1924
  _globals['_GROUPLEAVEREQUEST']._serialized_start=1926
  _globals['_GROUPLEAVEREQUEST']._serialized_end=1972
  _globals['_GROUPLEAVERESPONSE']._serialized_start=1974
  _globals['_GROUPLEAVERESPONSE']._serialized_end=2050
  _globals['_GROUPUPDATEREQUEST']._serialized_start=2052
  _globals['_GROUPUPDATEREQUEST']._serialized_end=2128
  _globals['_GROUPUPDATERESPONSE']._serialized_start=2130
  _globals['_GROUPUPDATERESPONSE']._serialized_end=2207
  _globals['_GROUPUNSETPHOTOREQUEST']._serialized_start=2209
  _globals['_GROUPUNSETPHOTOREQUEST']._serialized_end=2260
  _globals['_GROUPUNSETPHOTORESPONSE']._serialized_start=2262
  _globals['_GROUPUNSETPHOTORESPONSE']._serialized_end=2343
  _globals['_GROUPSETPHOTOREQUESTMETADATA']._serialized_start=2345
  _globals['_GROUPSETPHOTOREQUESTMETADATA']._serialized_end=2459
  _globals['_GROUPSETPHOTOREQUEST']._serialized_start=2462
  _globals['_GROUPSETPHOTOREQUEST']._serialized_end=2608
  _globals['_GROUPSETPHOTORESPONSE']._serialized_start=2610
  _globals['_GROUPSETPHOTORESPONSE']._serialized_end=2689
  _globals['_GROUPDOWNLOADPHOTOREQUEST']._serialized_start=2691
  _globals['_GROUPDOWNLOADPHOTOREQUEST']._serialized_end=2745
  _globals['_GROUPDOWNLOADPHOTORESPONSE']._serialized_start=2747
  _globals['_GROUPDOWNLOADPHOTORESPONSE']._serialized_end=2797
# @@protoc_insertion_point(module_scope)



from .notifications import SubscribeToAttachmentReceivedNotification, AttachmentReceivedNotification, SubscribeToAttachmentUploadedNotification, AttachmentUploadedNotification, SubscribeToCallIncomingCallNotification, CallIncomingCallNotification, SubscribeToCallRingingNotification, CallRingingNotification, SubscribeToCallAcceptedNotification, CallAcceptedNotification, SubscribeToCallDeclinedNotification, CallDeclinedNotification, SubscribeToCallBusyNotification, CallBusyNotification, SubscribeToCallEndedNotification, CallEndedNotification, SubscribeToContactNewNotification, ContactNewNotification, SubscribeToContactDeletedNotification, ContactDeletedNotification, SubscribeToContactDetailsUpdatedNotification, ContactDetailsUpdatedNotification, SubscribeToContactPhotoUpdatedNotification, ContactPhotoUpdatedNotification, SubscribeToDiscussionNewNotification, DiscussionNewNotification, SubscribeToDiscussionLockedNotification, DiscussionLockedNotification, SubscribeToDiscussionTitleUpdatedNotification, DiscussionTitleUpdatedNotification, SubscribeToDiscussionSettingsUpdatedNotification, DiscussionSettingsUpdatedNotification, SubscribeToGroupNewNotification, GroupNewNotification, SubscribeToGroupDeletedNotification, GroupDeletedNotification, SubscribeToGroupNameUpdatedNotification, GroupNameUpdatedNotification, SubscribeToGroupPhotoUpdatedNotification, GroupPhotoUpdatedNotification, SubscribeToGroupDescriptionUpdatedNotification, GroupDescriptionUpdatedNotification, SubscribeToGroupPendingMemberAddedNotification, GroupPendingMemberAddedNotification, SubscribeToGroupPendingMemberRemovedNotification, GroupPendingMemberRemovedNotification, SubscribeToGroupMemberJoinedNotification, GroupMemberJoinedNotification, SubscribeToGroupMemberLeftNotification, GroupMemberLeftNotification, SubscribeToGroupOwnPermissionsUpdatedNotification, GroupOwnPermissionsUpdatedNotification, SubscribeToGroupMemberPermissionsUpdatedNotification, GroupMemberPermissionsUpdatedNotification, SubscribeToIdentityCreatedNotification, IdentityCreatedNotification, SubscribeToIdentityDeletedNotification, IdentityDeletedNotification, SubscribeToIdentityUpdatedNotification, IdentityDetailsUpdatedNotification, SubscribeToInvitationReceivedNotification, InvitationReceivedNotification, SubscribeToInvitationSentNotification, InvitationSentNotification, SubscribeToInvitationDeletedNotification, InvitationDeletedNotification, SubscribeToInvitationUpdatedNotification, InvitationUpdatedNotification, SubscribeToMessageReceivedNotification, MessageReceivedNotification, SubscribeToMessageSentNotification, MessageSentNotification, SubscribeToMessageDeletedNotification, MessageDeletedNotification, SubscribeToMessageBodyUpdatedNotification, MessageBodyUpdatedNotification, SubscribeToMessageUploadedNotification, MessageUploadedNotification, SubscribeToMessageDeliveredNotification, MessageDeliveredNotification, SubscribeToMessageReadNotification, MessageReadNotification, SubscribeToMessageLocationReceivedNotification, MessageLocationReceivedNotification, SubscribeToMessageLocationSentNotification, MessageLocationSentNotification, SubscribeToMessageLocationSharingStartNotification, MessageLocationSharingStartNotification, SubscribeToMessageLocationSharingUpdateNotification, MessageLocationSharingUpdateNotification, SubscribeToMessageLocationSharingEndNotification, MessageLocationSharingEndNotification, SubscribeToMessageReactionAddedNotification, MessageReactionAddedNotification, SubscribeToMessageReactionUpdatedNotification, MessageReactionUpdatedNotification, SubscribeToMessageReactionRemovedNotification, MessageReactionRemovedNotification, InvitationNotificationServiceStub, ContactNotificationServiceStub, GroupNotificationServiceStub, DiscussionNotificationServiceStub, MessageNotificationServiceStub, AttachmentNotificationServiceStub, CallNotificationServiceStub
del notifications



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/notification/v1/contact_notifications.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/notification/v1/contact_notifications.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import contact_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_contact__pb2
from .....olvid.daemon.datatypes.v1 import identity_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_identity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8olvid/daemon/notification/v1/contact_notifications.proto\x12\x1colvid.daemon.notification.v1\x1a\'olvid/daemon/datatypes/v1/contact.proto\x1a(olvid/daemon/datatypes/v1/identity.proto\"\x9a\x01\n!SubscribeToContactNewNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x06\x66ilter\x18\x02 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.ContactFilterH\x01R\x06\x66ilter\x88\x01\x01\x42\x08\n\x06_countB\t\n\x07_filter\"V\n\x16\x43ontactNewNotification\x12<\n\x07\x63ontact\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.ContactR\x07\x63ontact\"\xbf\x01\n%SubscribeToContactDeletedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x06\x66ilter\x18\x02 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.ContactFilterH\x01R\x06\x66ilter\x88\x01\x01\x12\x1f\n\x0b\x63ontact_ids\x18\x03 \x03(\x04R\ncontactIdsB\x08\n\x06_countB\t\n\x07_filter\"Z\n\x1a\x43ontactDeletedNotification\x12<\n\x07\x63ontact\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.ContactR\x07\x63ontact\"\xc6\x01\n,SubscribeToContactDetailsUpdatedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x06\x66ilter\x18\x02 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.ContactFilterH\x01R\x06\x66ilter\x88\x01\x01\x12\x1f\n\x0b\x63ontact_ids\x18\x03 \x03(\x04R\ncontactIdsB\x08\n\x06_countB\t\n\x07_filter\"\xb8\x01\n!ContactDetailsUpdatedNotification\x12<\n\x07\x63ontact\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.ContactR\x07\x63ontact\x12U\n\x10previous_details\x18\x02 \x01(\x0b\x32*.olvid.daemon.datatypes.v1.IdentityDetailsR\x0fpreviousDetails\"\xc4\x01\n*SubscribeToContactPhotoUpdatedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x45\n\x06\x66ilter\x18\x02 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.ContactFilterH\x01R\x06\x66ilter\x88\x01\x01\x12\x1f\n\x0b\x63ontact_ids\x18\x03 \x03(\x04R\ncontactIdsB\x08\n\x06_countB\t\n\x07_filter\"_\n\x1f\x43ontactPhotoUpdatedNotification\x12<\n\x07\x63ontact\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.ContactR\x07\x63ontactB\xe1\x01\n com.olvid.daemon.notification.v1B\x19\x43ontactNotificationsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODN\xaa\x02\x1cOlvid.Daemon.Notification.V1\xca\x02\x1cOlvid\\Daemon\\Notification\\V1\xe2\x02(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\xea\x02\x1fOlvid::Daemon::Notification::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.notification.v1.contact_notifications_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.olvid.daemon.notification.v1B\031ContactNotificationsProtoP\001Z\017olvid.io/daemon\242\002\003ODN\252\002\034Olvid.Daemon.Notification.V1\312\002\034Olvid\\Daemon\\Notification\\V1\342\002(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\352\002\037Olvid::Daemon::Notification::V1'
  _globals['_SUBSCRIBETOCONTACTNEWNOTIFICATION']._serialized_start=174
  _globals['_SUBSCRIBETOCONTACTNEWNOTIFICATION']._serialized_end=328
  _globals['_CONTACTNEWNOTIFICATION']._serialized_start=330
  _globals['_CONTACTNEWNOTIFICATION']._serialized_end=416
  _globals['_SUBSCRIBETOCONTACTDELETEDNOTIFICATION']._serialized_start=419
  _globals['_SUBSCRIBETOCONTACTDELETEDNOTIFICATION']._serialized_end=610
  _globals['_CONTACTDELETEDNOTIFICATION']._serialized_start=612
  _globals['_CONTACTDELETEDNOTIFICATION']._serialized_end=702
  _globals['_SUBSCRIBETOCONTACTDETAILSUPDATEDNOTIFICATION']._serialized_start=705
  _globals['_SUBSCRIBETOCONTACTDETAILSUPDATEDNOTIFICATION']._serialized_end=903
  _globals['_CONTACTDETAILSUPDATEDNOTIFICATION']._serialized_start=906
  _globals['_CONTACTDETAILSUPDATEDNOTIFICATION']._serialized_end=1090
  _globals['_SUBSCRIBETOCONTACTPHOTOUPDATEDNOTIFICATION']._serialized_start=1093
  _globals['_SUBSCRIBETOCONTACTPHOTOUPDATEDNOTIFICATION']._serialized_end=1289
  _globals['_CONTACTPHOTOUPDATEDNOTIFICATION']._serialized_start=1291
  _globals['_CONTACTPHOTOUPDATEDNOTIFICATION']._serialized_end=1386
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/datatypes/v1/storage.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/datatypes/v1/storage.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'olvid/daemon/datatypes/v1/storage.proto\x12\x19olvid.daemon.datatypes.v1\"8\n\x0eStorageElement\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\"\x82\x01\n\x14StorageElementFilter\x12\"\n\nkey_search\x18\x01 \x01(\tH\x00R\tkeySearch\x88\x01\x01\x12&\n\x0cvalue_search\x18\x02 \x01(\tH\x01R\x0bvalueSearch\x88\x01\x01\x42\r\n\x0b_key_searchB\x0f\n\r_value_searchB\xc5\x01\n\x1d\x63om.olvid.daemon.datatypes.v1B\x0cStorageProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODD\xaa\x02\x19Olvid.Daemon.Datatypes.V1\xca\x02\x19Olvid\\Daemon\\Datatypes\\V1\xe2\x02%Olvid\\Daemon\\Datatypes\\V1\\GPBMetadata\xea\x02\x1cOlvid::Daemon::Datatypes::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.datatypes.v1.storage_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.olvid.daemon.datatypes.v1B\014StorageProtoP\001Z\017olvid.io/daemon\242\002\003ODD\252\002\031Olvid.Daemon.Datatypes.V1\312\002\031Olvid\\Daemon\\Datatypes\\V1\342\002%Olvid\\Daemon\\Datatypes\\V1\\GPBMetadata\352\002\034Olvid::Daemon::Datatypes::V1'
  _globals['_STORAGEELEMENT']._serialized_start=70
  _globals['_STORAGEELEMENT']._serialized_end=126
  _globals['_STORAGEELEMENTFILTER']._serialized_start=129
  _globals['_STORAGEELEMENTFILTER']._serialized_end=259
# @@protoc_insertion_point(module_scope)



from __future__ import annotations  # this block is necessary for compilation
from typing import Optional, Callable, Any

from grpc import Channel

from ..internal import commands, notifications, admin

from typing import TYPE_CHECKING  # this block is necessary for compilation
if TYPE_CHECKING:  # this block is necessary for compilation
	from .OlvidClient import OlvidClient


class StubHolder:
	def __init__(self, client: "OlvidClient", channel: Channel, parent: Optional[OlvidClient] = None):
		self._client: OlvidClient = client
		self._parent: Optional[OlvidClient] = parent
		self._channel: Channel = channel

		# create command stubs
		self.identityCommandStub: commands.IdentityCommandServiceStub = self._get_or_create_stub(
			"identityCommandStub", commands.IdentityCommandServiceStub)
		self.invitationCommandStub: commands.InvitationCommandServiceStub = self._get_or_create_stub(
			"invitationCommandStub", commands.InvitationCommandServiceStub)
		self.contactCommandStub: commands.ContactCommandServiceStub = self._get_or_create_stub("contactCommandStub",
																								commands.ContactCommandServiceStub)
		self.keycloakCommandStub: commands.KeycloakCommandServiceStub = self._get_or_create_stub("keycloakCommandStub",
																								commands.KeycloakCommandServiceStub)
		self.groupCommandStub: commands.GroupCommandServiceStub = self._get_or_create_stub("groupCommandStub",
																							commands.GroupCommandServiceStub)
		self.discussionCommandStub: commands.DiscussionCommandServiceStub = self._get_or_create_stub(
			"discussionCommandStub", commands.DiscussionCommandServiceStub)
		self.messageCommandStub: commands.MessageCommandServiceStub = self._get_or_create_stub("messageCommandStub",
																								commands.MessageCommandServiceStub)
		self.attachmentCommandStub: commands.AttachmentCommandServiceStub = self._get_or_create_stub(
			"attachmentCommandStub", commands.AttachmentCommandServiceStub)
		self.storageCommandStub: commands.StorageCommandServiceStub = self._get_or_create_stub("storageCommandStub",
																								commands.StorageCommandServiceStub)
		self.discussionStorageCommandStub: commands.DiscussionStorageCommandServiceStub = self._get_or_create_stub(
			"discussionStorageCommandStub", commands.DiscussionStorageCommandServiceStub)
		self.callCommandStub: commands.CallCommandServiceStub = self._get_or_create_stub(
			"callCommandStub", commands.CallCommandServiceStub)
		self.toolCommandStub: commands.ToolCommandServiceStub = self._get_or_create_stub(
			"toolCommandStub", commands.ToolCommandServiceStub)
		self.settingsCommandStub: commands.SettingsCommandServiceStub = self._get_or_create_stub(
			"settingsCommandStub", commands.SettingsCommandServiceStub)

		# create notification stubs
		self.invitationNotificationStub: notifications.InvitationNotificationServiceStub = self._get_or_create_stub(
			"invitationNotificationStub", notifications.InvitationNotificationServiceStub)
		self.contactNotificationStub: notifications.ContactNotificationServiceStub = self._get_or_create_stub(
			"contactNotificationStub", notifications.ContactNotificationServiceStub)
		self.groupNotificationStub: notifications.GroupNotificationServiceStub = self._get_or_create_stub(
			"groupNotificationStub", notifications.GroupNotificationServiceStub)
		self.discussionNotificationStub: notifications.DiscussionNotificationServiceStub = self._get_or_create_stub(
			"discussionNotificationStub", notifications.DiscussionNotificationServiceStub)
		self.messageNotificationStub: notifications.MessageNotificationServiceStub = self._get_or_create_stub(
			"messageNotificationStub", notifications.MessageNotificationServiceStub)
		self.attachmentNotificationStub: notifications.AttachmentNotificationServiceStub = self._get_or_create_stub(
			"attachmentNotificationStub", notifications.AttachmentNotificationServiceStub)
		self.callNotificationStub: notifications.CallNotificationServiceStub = self._get_or_create_stub(
			"callNotificationStub", notifications.CallNotificationServiceStub)

		# do not create admin stubs
		self.clientKeyAdminStub: Optional[admin.ClientKeyAdminServiceStub] = None
		self.identityAdminStub: Optional[admin.IdentityAdminServiceStub] = None
		self.backupAdminStub: Optional[admin.BackupAdminServiceStub] = None

	def create_admin_stubs(self):
		self.clientKeyAdminStub: admin.ClientKeyAdminServiceStub = self._get_or_create_stub("clientKeyAdminStub", admin.ClientKeyAdminServiceStub)
		self.identityAdminStub: admin.IdentityAdminServiceStub = self._get_or_create_stub("identityAdminStub", admin.IdentityAdminServiceStub)
		self.backupAdminStub: admin.BackupAdminServiceStub = self._get_or_create_stub("backupAdminStub", admin.BackupAdminServiceStub)

	def _get_or_create_stub(self, attribute_name: str, stub_class: Callable[[Callable[[], list[tuple[str, str]]], Channel], Any]):
		if not self._parent:
			return stub_class(self._client.get_grpc_metadata, self._channel)
		if not hasattr(self._parent._stubs, attribute_name):
			return stub_class(self._client.get_grpc_metadata, self._channel)
		return getattr(self._parent._stubs, attribute_name)



import asyncio
from typing import Optional

import readline
import asyncclick as click

from .ClientSingleton import ClientSingleton
from ...core.OlvidAdminClient import OlvidAdminClient
from ...datatypes import datatypes
from ...listeners import ListenersImplementation as listeners
from ...core import errors
from .cli_tools import print_warning_message

def interactive_command(func):
	def wrapper(*args, **kwargs):
		if ClientSingleton.is_script_mode_enabled():
			print_warning_message("WARNING: launching interactive command in script mode")
		try:
			# disable history in interactive mode
			readline.set_auto_history(False)
			return func(*args, **kwargs)
		finally:
			# re-enable history in interactive mode
			readline.set_auto_history(True)
	return wrapper


# raise AbortException
@interactive_command
async def ask_question_with_context(question: str, prompt: str = None, fg_color: str = None, bg_color: str = None) -> bool:
	if prompt:
		prompt += " > "
	if prompt and (fg_color or bg_color):
		prompt = click.style(prompt, fg=fg_color, bg=bg_color)
	return await click.prompt(prompt + question, type=bool, prompt_suffix=" (y/N)\n>")


@interactive_command
async def prompt_with_context(question: str, prompt: str = None, fg_color: str = None, bg_color: str = None) -> str:
	if prompt:
		prompt += " > "
	if prompt and (fg_color or bg_color):
		prompt = click.style(prompt, fg=fg_color, bg=bg_color)
	return await click.prompt(prompt + question, type=str, prompt_suffix="\n>")


def print_with_context(text: str, prompt: str = None, fg_color: str = None, bg_color: str = None):
	if prompt:
		prompt += " > "
	if prompt and (fg_color or bg_color):
		prompt = click.style(prompt, fg=fg_color, bg=bg_color)
	print(prompt + text)


# show invitation link and wait for an invitation to arrive to complete it interactively
async def contact_new(identity_id: int, prompt: str = None, fg_color: str = None, bg_color: str = None) -> Optional[datatypes.Discussion]:
	identity: datatypes.Identity = await ClientSingleton.get_client().admin_identity_admin_get(identity_id=identity_id)
	print_with_context(f"Send an invitation to this invitation link: {identity.invitation_url}", prompt=prompt, fg_color=fg_color, bg_color=bg_color)

	# create invitation received listener
	client: OlvidAdminClient = OlvidAdminClient(identity_id=identity_id)
	invitations: list[datatypes.Invitation] = []
	client.add_listener(listeners.InvitationReceivedListener(handler=lambda i: invitations.append(i), count=1, filter=datatypes.InvitationFilter(status=datatypes.Invitation.Status.STATUS_INVITATION_WAIT_YOU_TO_ACCEPT)))
	await client.wait_for_listeners_end()

	return await handle_invitation_interactively(client=client, invitation=invitations[0], prompt=prompt, fg_color=fg_color, bg_color=bg_color)


# send an invitation and complete it interactively
async def invitation_new(identity_id: int, invitation: datatypes.Invitation, prompt: str = None, fg_color: str = None, bg_color: str = None) -> Optional[datatypes.Discussion]:
	client: OlvidAdminClient = OlvidAdminClient(identity_id=identity_id)
	return await handle_invitation_interactively(client=client, invitation=invitation, prompt=prompt, fg_color=fg_color, bg_color=bg_color)


# a loop to complete interactively an invitation process
async def handle_invitation_interactively(client: OlvidAdminClient, invitation: datatypes.Invitation, prompt: str = None, fg_color: str = None, bg_color: str = None) -> Optional[datatypes.Discussion]:
	# create discussion new listener
	discussion_new_client = OlvidAdminClient(identity_id=client.current_identity_id)
	discussions: list[datatypes.Discussion] = []
	discussion_new_client.add_listener(listeners.DiscussionNewListener(handler=lambda i: discussions.append(i), count=1))

	first_sas: bool = True
	while True:
		# refresh invitation, stop loop if invitation was deleted
		try:
			invitation = await client.invitation_get(invitation_id=invitation.id)
		except errors.NotFoundError:
			break
		if invitation.status == datatypes.Invitation.Status.STATUS_INVITATION_WAIT_YOU_TO_ACCEPT:
			await client.invitation_accept(invitation_id=invitation.id)
			await asyncio.sleep(0.1)
		elif invitation.status == datatypes.Invitation.Status.STATUS_INVITATION_WAIT_IT_TO_ACCEPT:
			print_with_context("Waiting for other device to accept invitation ...", prompt=prompt, fg_color=fg_color, bg_color=bg_color)
			invitation = await invitation.wait_for_update(client=client)
		elif invitation.status == datatypes.Invitation.Status.STATUS_INVITATION_WAIT_IT_FOR_SAS_EXCHANGE:
			print_with_context(f"Please enter this code on the other device: {invitation.sas}", prompt=prompt, fg_color=fg_color, bg_color=bg_color)
			update_or_delete_client = OlvidAdminClient(identity_id=client.current_identity_id)
			update_or_delete_client.add_listener(listeners.InvitationUpdatedListener(handler=lambda i, pi: update_or_delete_client.stop(), invitation_ids=[invitation.id]))
			update_or_delete_client.add_listener(listeners.InvitationDeletedListener(handler=lambda i: update_or_delete_client.stop(), invitation_ids=[invitation.id]))
			await update_or_delete_client.wait_for_listeners_end()
		elif invitation.status == datatypes.Invitation.Status.STATUS_INVITATION_STATUS_IN_PROGRESS:
			invitation = await invitation.wait_for_update(client=client)
		elif invitation.status == datatypes.Invitation.Status.STATUS_INVITATION_WAIT_YOU_FOR_SAS_EXCHANGE:
			if not first_sas:
				print_with_context("Invalid sas code", prompt=prompt, fg_color=fg_color, bg_color=bg_color)
			if invitation.sas:
				print_with_context(f"Your code: {invitation.sas}", prompt=prompt, fg_color=fg_color, bg_color=bg_color)
			sas_code: str = await prompt_with_context("Please enter code displayed on the other device", prompt=prompt, fg_color=fg_color, bg_color=bg_color)
			try:
				await client.invitation_sas(invitation_id=invitation.id, sas=sas_code)
			except errors.AioRpcError:
				pass
			first_sas = False
			await asyncio.sleep(0.1)

	await discussion_new_client.stop()
	return discussions[0] if discussions else None



import asyncio
import sys
import threading

import asyncclick as click

from .interactive_tree import interactive_tree
from .tools.ClientSingleton import ClientSingleton
from .tools.cli_tools import print_error_message
from .tools.exceptions import CancelCommandError
from ..core import errors


def tokenize_command_line(cmd_line: str) -> list[str]:
	tokens: list[str] = []
	current_token: str = ''
	in_quote: str = ""  # contains current quoting character
	escape_next: bool = False

	for char in cmd_line:
		if char == '\\' and in_quote != '\'':
			# Handle escaping the next character
			escape_next = True
		elif char in ['"', "'"] and not (in_quote and char != in_quote):
			# Toggle quote mode
			in_quote = "" if in_quote else char
			if not in_quote:
				tokens.append(current_token)
				current_token = ''
		# Add the escaped character to the current token
		elif escape_next or in_quote:
			current_token += char
			escape_next = False
		elif char == ' ' and not in_quote and not escape_next:
			if current_token:
				tokens.append(current_token)
				current_token = ''
		else:
			current_token += char

	if current_token:
		tokens.append(current_token)

	return tokens


class InputThread(threading.Thread):
	def __init__(self, loop: asyncio.AbstractEventLoop):
		super().__init__()
		self.loop: asyncio.AbstractEventLoop = loop
		# event set when main wants InputThread to start input
		self.read_event: threading.Event = threading.Event()
		# Allow the thread to exit when the main program finishes
		self.daemon = True
		self.stop: bool = False
		self.queue = asyncio.Queue()

	async def read_main(self):
		while not self.stop:
			try:
				self.read_event.wait()
				self.read_event.clear()
				self.loop.call_soon_threadsafe(self.queue.put_nowait, input(f"{ClientSingleton.get_current_identity_id()} > "))
			except EOFError:
				self.stop = True
				self.loop.call_soon_threadsafe(self.queue.put_nowait, None)
				break
			except KeyboardInterrupt:
				self.loop.call_soon_threadsafe(self.queue.put_nowait, None)

	def run(self):
		asyncio.set_event_loop(asyncio.new_event_loop())
		asyncio.get_event_loop().run_until_complete(self.read_main())


async def interactive_main():
	# this import is important to enable the command line edition in interactive mode
	import readline

	# add exit command
	interactive_tree.add_command(click.Command("exit", callback=lambda *args, **kwargs: sys.exit(0)))
	interactive_tree.add_command(click.Command("quit", callback=lambda *args, **kwargs: sys.exit(0), hidden=True))

	# setup history
	try:
		readline.read_history_file("./.cli_history")
	except FileNotFoundError:
		pass
	except Exception:
		print_error_message("Cannot load cli history")
	readline.set_history_length(200)
	readline.set_auto_history(True)
	# auto select current identity if not specified in options
	try:
		if not ClientSingleton.get_current_identity_id():
			await ClientSingleton.auto_select_identity()
	except errors.UnavailableError:
		print_error_message(f"Cannot connect to server: {ClientSingleton.get_client().server_target}")
		return
	except errors.AioRpcError as e:
		print_error_message(e.details())
		return

	try:
		input_thread = InputThread(asyncio.get_event_loop())
		input_thread.start()

		while not input_thread.stop:
			try:
				input_thread.read_event.set()
				line = await input_thread.queue.get()
				if line is None:
					continue
				# line = await asyncio.to_thread(input, f"{ClientSingleton.get_current_identity_id()} > ")
				# print("post input")
				tokens: list[str] = tokenize_command_line(line)

				# shortcut for current identity
				if tokens and tokens[0].isdigit():
					# no command, just change current identity
					if len(tokens) == 1:
						ClientSingleton.set_current_identity_id(identity_id=int(tokens[0]))
						click.secho(f"Now using identity: {ClientSingleton.get_current_identity_id()}", fg="green")
					# execute command as specified identity
					else:
						previous_identity: int = ClientSingleton.get_current_identity_id()
						ClientSingleton.set_current_identity_id(identity_id=int(tokens[0]))
						try:
							click.secho(f"Executing command as {ClientSingleton.get_current_identity_id()}", fg="green")
							await interactive_tree.main(tokens[1:], prog_name="olvid-cli", standalone_mode=False)
						finally:
							ClientSingleton.set_current_identity_id(previous_identity)
					continue
				# normal case
				else:
					await interactive_tree.main(tokens, prog_name="olvid-cli", standalone_mode=False)
			except CancelCommandError:
				continue
			except click.UsageError as e:
				# NoArgsIsHelpError error is raised for incomplete commands (`message`, `settings discussion`)
				# in that case e.format_message already returns help message
				if type(e).__name__ == "NoArgsIsHelpError":
					print(e.format_message())
				# for other error show error message in red and help message in white
				else:
					click.echo(click.style(e.format_message(), fg="red"))
					if e.ctx is not None:
						print(e.ctx.get_help())
			# clean line on ctrl + c
			except (KeyboardInterrupt, asyncio.CancelledError):
				break
			# handle ctrl + d
			except EOFError:
				break
			except ValueError:
				break
	finally:
		# save history
		readline.write_history_file("./.cli_history")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/services/v1/admin_service.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/services/v1/admin_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.admin.v1 import backup_admin_pb2 as olvid_dot_daemon_dot_admin_dot_v1_dot_backup__admin__pb2
from .....olvid.daemon.admin.v1 import client_key_admin_pb2 as olvid_dot_daemon_dot_admin_dot_v1_dot_client__key__admin__pb2
from .....olvid.daemon.admin.v1 import identity_admin_pb2 as olvid_dot_daemon_dot_admin_dot_v1_dot_identity__admin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,olvid/daemon/services/v1/admin_service.proto\x12\x18olvid.daemon.services.v1\x1a(olvid/daemon/admin/v1/backup_admin.proto\x1a,olvid/daemon/admin/v1/client_key_admin.proto\x1a*olvid/daemon/admin/v1/identity_admin.proto2\xd1\x03\n\x15\x43lientKeyAdminService\x12n\n\rClientKeyList\x12+.olvid.daemon.admin.v1.ClientKeyListRequest\x1a,.olvid.daemon.admin.v1.ClientKeyListResponse\"\x00\x30\x01\x12i\n\x0c\x43lientKeyGet\x12*.olvid.daemon.admin.v1.ClientKeyGetRequest\x1a+.olvid.daemon.admin.v1.ClientKeyGetResponse\"\x00\x12i\n\x0c\x43lientKeyNew\x12*.olvid.daemon.admin.v1.ClientKeyNewRequest\x1a+.olvid.daemon.admin.v1.ClientKeyNewResponse\"\x00\x12r\n\x0f\x43lientKeyDelete\x12-.olvid.daemon.admin.v1.ClientKeyDeleteRequest\x1a..olvid.daemon.admin.v1.ClientKeyDeleteResponse\"\x00\x32\xb0\x08\n\x14IdentityAdminService\x12k\n\x0cIdentityList\x12*.olvid.daemon.admin.v1.IdentityListRequest\x1a+.olvid.daemon.admin.v1.IdentityListResponse\"\x00\x30\x01\x12u\n\x10IdentityAdminGet\x12..olvid.daemon.admin.v1.IdentityAdminGetRequest\x1a/.olvid.daemon.admin.v1.IdentityAdminGetResponse\"\x00\x12\xa2\x01\n\x1fIdentityAdminGetBytesIdentifier\x12=.olvid.daemon.admin.v1.IdentityAdminGetBytesIdentifierRequest\x1a>.olvid.daemon.admin.v1.IdentityAdminGetBytesIdentifierResponse\"\x00\x12\x9f\x01\n\x1eIdentityAdminGetInvitationLink\x12<.olvid.daemon.admin.v1.IdentityAdminGetInvitationLinkRequest\x1a=.olvid.daemon.admin.v1.IdentityAdminGetInvitationLinkResponse\"\x00\x12\x93\x01\n\x1aIdentityAdminDownloadPhoto\x12\x38.olvid.daemon.admin.v1.IdentityAdminDownloadPhotoRequest\x1a\x39.olvid.daemon.admin.v1.IdentityAdminDownloadPhotoResponse\"\x00\x12o\n\x0eIdentityDelete\x12,.olvid.daemon.admin.v1.IdentityDeleteRequest\x1a-.olvid.daemon.admin.v1.IdentityDeleteResponse\"\x00\x12\x66\n\x0bIdentityNew\x12).olvid.daemon.admin.v1.IdentityNewRequest\x1a*.olvid.daemon.admin.v1.IdentityNewResponse\"\x00\x12~\n\x13IdentityKeycloakNew\x12\x31.olvid.daemon.admin.v1.IdentityKeycloakNewRequest\x1a\x32.olvid.daemon.admin.v1.IdentityKeycloakNewResponse\"\x00\x32\xe0\x06\n\x12\x42\x61\x63kupAdminService\x12i\n\x0c\x42\x61\x63kupKeyGet\x12*.olvid.daemon.admin.v1.BackupKeyGetRequest\x1a+.olvid.daemon.admin.v1.BackupKeyGetResponse\"\x00\x12o\n\x0e\x42\x61\x63kupKeyRenew\x12,.olvid.daemon.admin.v1.BackupKeyRenewRequest\x1a-.olvid.daemon.admin.v1.BackupKeyRenewResponse\"\x00\x12`\n\tBackupGet\x12\'.olvid.daemon.admin.v1.BackupGetRequest\x1a(.olvid.daemon.admin.v1.BackupGetResponse\"\x00\x12`\n\tBackupNow\x12\'.olvid.daemon.admin.v1.BackupNowRequest\x1a(.olvid.daemon.admin.v1.BackupNowResponse\"\x00\x12~\n\x13\x42\x61\x63kupRestoreDaemon\x12\x31.olvid.daemon.admin.v1.BackupRestoreDaemonRequest\x1a\x32.olvid.daemon.admin.v1.BackupRestoreDaemonResponse\"\x00\x12\x8d\x01\n\x18\x42\x61\x63kupRestoreAdminBackup\x12\x36.olvid.daemon.admin.v1.BackupRestoreAdminBackupRequest\x1a\x37.olvid.daemon.admin.v1.BackupRestoreAdminBackupResponse\"\x00\x12\x99\x01\n\x1c\x42\x61\x63kupRestoreProfileSnapshot\x12:.olvid.daemon.admin.v1.BackupRestoreProfileSnapshotRequest\x1a;.olvid.daemon.admin.v1.BackupRestoreProfileSnapshotResponse\"\x00\x42\xc5\x01\n\x1c\x63om.olvid.daemon.services.v1B\x11\x41\x64minServiceProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODS\xaa\x02\x18Olvid.Daemon.Services.V1\xca\x02\x18Olvid\\Daemon\\Services\\V1\xe2\x02$Olvid\\Daemon\\Services\\V1\\GPBMetadata\xea\x02\x1bOlvid::Daemon::Services::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.services.v1.admin_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.olvid.daemon.services.v1B\021AdminServiceProtoP\001Z\017olvid.io/daemon\242\002\003ODS\252\002\030Olvid.Daemon.Services.V1\312\002\030Olvid\\Daemon\\Services\\V1\342\002$Olvid\\Daemon\\Services\\V1\\GPBMetadata\352\002\033Olvid::Daemon::Services::V1'
  _globals['_CLIENTKEYADMINSERVICE']._serialized_start=207
  _globals['_CLIENTKEYADMINSERVICE']._serialized_end=672
  _globals['_IDENTITYADMINSERVICE']._serialized_start=675
  _globals['_IDENTITYADMINSERVICE']._serialized_end=1747
  _globals['_BACKUPADMINSERVICE']._serialized_start=1750
  _globals['_BACKUPADMINSERVICE']._serialized_end=2614
# @@protoc_insertion_point(module_scope)



import logging

from ClientHolder import ClientHolder, ClientWrapper
from utils.tools_message import send_message_wait_and_check_content
from utils.tools_reaction import react_message


# noinspection PyProtectedMember,DuplicatedCode
async def first_routine(client_1: ClientWrapper, client_2: ClientWrapper):
	# send a message to react to
	sent_message, received_message = await send_message_wait_and_check_content(client_1, client_2, "Message to react to")
	contact_2 = await client_2.get_contact_associated_to_another_client(other_client=client_1)

	####
	# Add reaction
	####
	reaction_1, reaction_2 = await react_message(client_1, client_2, sent_message.id, received_message.id, "A")
	assert reaction_1.reaction == reaction_2.reaction == "A"
	assert reaction_1.contact_id == 0
	assert reaction_2.contact_id == contact_2.id

	reaction_1, reaction_2 = await react_message(client_1, client_2, sent_message.id, received_message.id, "B")
	assert reaction_1.reaction == reaction_2.reaction == "B"
	assert reaction_1.contact_id == 0
	assert reaction_2.contact_id == contact_2.id
	reaction_1, reaction_2 = await react_message(client_1, client_2, sent_message.id, received_message.id, "C")
	assert reaction_1.reaction == reaction_2.reaction == "C"
	assert reaction_1.contact_id == 0
	assert reaction_2.contact_id == contact_2.id

	await react_message(client_1, client_2, sent_message.id, received_message.id, "")


# noinspection PyUnusedLocal
async def test_reaction(client_holder: ClientHolder, fast_mode):
	for c1, c2 in client_holder.get_one_client_pair_and_reverse():
		logging.info(f"Reaction routine: {c1.identity.id} <-> {c2.identity.id}")
		await first_routine(c1, c2)



import logging

from olvid import OlvidClient, datatypes, listeners, errors

from ClientHolder import ClientHolder, ClientWrapper

from utils.tools_message import send_message_wait_and_check_content

test_failed = False


async def count_identity_messages(client: OlvidClient) -> int:
	count = 0
	async for _ in client.message_list():
		count += 1
	return count


# send a message, then a message replying to the first message, and finally update the last message body
# every message is sent twice, one by identity
async def send_reply_and_edit_messages(client_1: ClientWrapper, client_2: ClientWrapper):
	# get message count for a final check
	initial_message_count_1 = await count_identity_messages(client_1)
	initial_message_count_2 = await count_identity_messages(client_2)
	sent_message_count = 0

	# get discussions and contacts
	discussion_1, discussion_2 = await client_1.get_discussion_associated_to_another_client(client_2), await client_2.get_discussion_associated_to_another_client(client_1)
	contact_1, contact_2 = await client_1.get_contact_associated_to_another_client(client_2), await client_2.get_contact_associated_to_another_client(client_1)

	# send normal message
	sent_message_count += 1
	original_message_1, original_message_2 = await send_message_wait_and_check_content(client_1, client_2, "A")
	# original_message_2, _ = await send_message_wait_and_check_content(client_2, client_1, "B")
	logging.info("Message send finished")

	# send reply message
	sent_message_count += 1
	reply_message_1, _ = await send_message_wait_and_check_content(client_1, client_2, f"reply {client_1.identity.id}", replied_message_ids=(original_message_1.id, original_message_2.id))
	# reply_message_2, _ = await send_message_wait_and_check_content(client_2, client_1, f"reply {client_2.identity.id}", replied_message_ids=(original_message_2.id, original_message_1.id))
	logging.info("Message reply finished")

	# update message body
	ideal_updated_message_1 = datatypes.Message(discussion_id=discussion_1.id, sender_id=0, body=f"Updated body from {client_1.identity.id}", replied_message_id=original_message_1.id, edited_body=True)
	ideal_updated_message_2 = datatypes.Message(discussion_id=discussion_2.id, sender_id=contact_2.id, body=f"Updated body from {client_1.identity.id}", replied_message_id=original_message_2.id, edited_body=True)
	bots = [
		client_1.create_notification_bot(listeners.MessageBodyUpdatedListener(handler=client_1.get_check_content_handler(ideal_updated_message_1, reply_message_1.body, notification_type=listeners.NOTIFICATIONS.MESSAGE_BODY_UPDATED), count=1)),
		client_2.create_notification_bot(listeners.MessageBodyUpdatedListener(handler=client_2.get_check_content_handler(ideal_updated_message_2, reply_message_1.body, notification_type=listeners.NOTIFICATIONS.MESSAGE_BODY_UPDATED), count=1)),
	]

	# update previous message
	await client_1.message_update_body(message_id=reply_message_1.id, updated_body=f"Updated body from {client_1.identity.id}")

	# wait for notif to arrive
	for bot in bots:
		await bot.wait_for_listeners_end()

	logging.info("Message body update finished")

	# check message count
	assert await count_identity_messages(client_1) == initial_message_count_1 + sent_message_count
	assert await count_identity_messages(client_2) == initial_message_count_2 + sent_message_count


async def delete_messages(client_1: ClientWrapper, client_2: ClientWrapper):
	# get discussions and contacts
	discussion_1, discussion_2 = await client_1.get_discussion_associated_to_another_client(
		client_2), await client_2.get_discussion_associated_to_another_client(client_1)

	#####
	# delete a message locally
	#####
	# retrieve a message to delete
	message_1 = None
	async for message in client_1.message_list():
		message_1 = message
	assert message_1

	bot = client_1.create_notification_bot(listeners.MessageDeletedListener(handler=client_1.get_check_content_handler(message_1, notification_type=listeners.NOTIFICATIONS.MESSAGE_DELETED), count=1))
	await client_1.message_delete(message_id=message_1.id)
	await bot.wait_for_listeners_end()

	#####
	# delete a message remotely
	#####
	message_1 = None
	async for message in client_1.message_list(filter=datatypes.MessageFilter(discussion_id=discussion_1.id)):
		message_1 = message
	message_2 = None
	async for message in client_2.message_list(filter=datatypes.MessageFilter(discussion_id=discussion_2.id)):
		if message.body == message_1.body:
			message_2 = message
	assert message_1, message_2

	bot_1 = client_1.create_notification_bot(listeners.MessageDeletedListener(handler=client_1.get_check_content_handler(message_1, notification_type=listeners.NOTIFICATIONS.MESSAGE_DELETED), count=1))
	bot_2 = client_2.create_notification_bot(listeners.MessageDeletedListener(handler=client_2.get_check_content_handler(message_2, notification_type=listeners.NOTIFICATIONS.MESSAGE_DELETED), count=1))

	await client_1.message_delete(message_id=message_1.id, delete_everywhere=True)

	await bot_1.wait_for_listeners_end()
	await bot_2.wait_for_listeners_end()

	try:
		message = await client_1.message_get(message_1.id)
		raise Exception(f"Found a deleted message: {message}")
	except errors.AioRpcError:
		pass
	except Exception:
		raise Exception("Invalid exception raised")

	try:
		message = await client_2.message_get(message_2.id)
		raise Exception(f"Found a deleted message: {message}")
	except errors.AioRpcError:
		pass
	except Exception:
		raise Exception("Invalid exception raised")


# noinspection PyUnusedLocal
async def test_message(client_holder: ClientHolder, fast_mode=False):
	for c1, c2 in client_holder.get_one_client_pair_and_reverse():
		logging.info(f"{c1.identity.id} <-> {c2.identity.id}: send and reply messages")
		await send_reply_and_edit_messages(c1, c2)
		logging.info(f"{c1.identity.id} <-> {c2.identity.id}: delete messages")
		await delete_messages(c1, c2)
		if test_failed:
			raise Exception("Test was marked as failed")



from grpc import StatusCode
from grpc.aio import AioRpcError, Metadata
from typing import Optional


class OlvidError(AioRpcError):
	def __init__(self, code: StatusCode = None, details: Optional[str] = None, initial_metadata: Metadata = None, trailing_metadata: Metadata = None, debug_error_string: Optional[str] = None):
		super().__init__(
			code=code,
			initial_metadata=initial_metadata if initial_metadata else Metadata(),
			trailing_metadata=trailing_metadata if trailing_metadata else Metadata(),
			details=details,
			debug_error_string=debug_error_string,
		)
		self._name: str = self.__class__.__name__

	def __str__(self):
		return f"{self._name}: {self._details}"

	@staticmethod
	def _from_aio_rpc_error(original_error: AioRpcError) -> AioRpcError:
		if original_error.code() == StatusCode.CANCELLED:
			return CancelledError(code=original_error.code(), initial_metadata=original_error.initial_metadata(), trailing_metadata=original_error.trailing_metadata(), details=original_error.details(), debug_error_string=original_error.debug_error_string())
		elif original_error.code() == StatusCode.INVALID_ARGUMENT:
			return InvalidArgumentError(code=original_error.code(), initial_metadata=original_error.initial_metadata(), trailing_metadata=original_error.trailing_metadata(), details=original_error.details(), debug_error_string=original_error.debug_error_string())
		elif original_error.code() == StatusCode.NOT_FOUND:
			return NotFoundError(code=original_error.code(), initial_metadata=original_error.initial_metadata(), trailing_metadata=original_error.trailing_metadata(), details=original_error.details(), debug_error_string=original_error.debug_error_string())
		elif original_error.code() == StatusCode.PERMISSION_DENIED:
			return PermissionDeniedError(code=original_error.code(), initial_metadata=original_error.initial_metadata(), trailing_metadata=original_error.trailing_metadata(), details=original_error.details(), debug_error_string=original_error.debug_error_string())
		elif original_error.code() == StatusCode.UNAUTHENTICATED:
			return UnauthenticatedError(code=original_error.code(), initial_metadata=original_error.initial_metadata(), trailing_metadata=original_error.trailing_metadata(), details=original_error.details(), debug_error_string=original_error.debug_error_string())
		elif original_error.code() == StatusCode.UNIMPLEMENTED:
			return UnimplementedError(code=original_error.code(), initial_metadata=original_error.initial_metadata(), trailing_metadata=original_error.trailing_metadata(), details=original_error.details(), debug_error_string=original_error.debug_error_string())
		elif original_error.code() == StatusCode.INTERNAL:
			return InternalError(code=original_error.code(), initial_metadata=original_error.initial_metadata(), trailing_metadata=original_error.trailing_metadata(), details=original_error.details(), debug_error_string=original_error.debug_error_string())
		elif original_error.code() == StatusCode.UNAVAILABLE:
			return UnavailableError(code=original_error.code(), initial_metadata=original_error.initial_metadata(), trailing_metadata=original_error.trailing_metadata(), details=original_error.details(), debug_error_string=original_error.debug_error_string())
		return original_error


"""
Exceptions triggered by Olvid Api
"""
class NotFoundError(OlvidError):
	"""
	The element you requested does not exist.
	"""
	pass

class InvalidArgumentError(OlvidError):
	"""
	The request you sent contains invalid fields, check error details to learn more.
	"""
	pass

class UnauthenticatedError(OlvidError):
	"""
	The client key you provided is not valid (or you haven't provided a client key).
	"""
	pass

class PermissionDeniedError(OlvidError):
	"""
	You tried to access admin methods with a non admin client key.
	"""
	pass

class InternalError(OlvidError):
	"""
	Something wrong happened daemon side. Check daemon logs to get more info.
	"""
	pass


"""
Exceptions triggered by gRPC you might see
"""
class UnavailableError(OlvidError):
	"""
	gRPC server is not available. Your daemon is probably not running or your client cannot connect to it.
	Check your connection url and port.
	"""
	pass

class CancelledError(OlvidError):
	"""
	The operation was cancelled, typically by the caller.
	This might happen if you force quit your program.
	"""
	pass

class UnimplementedError(OlvidError):
	"""
	Your daemon does not implement this method, check that your client and daemon version are the same.
	"""
	pass

# """
# Other gRPC exceptions
# """
# class DeadlineExceededError(AbstractError):
# 	pass
#
# class AlreadyExistsError(AbstractError):
# 	pass
#
# class ResourceExhaustedError(AbstractError):
# 	pass
#
# class FailedPreconditionError(AbstractError):
# 	pass
#
# class AbortedError(AbstractError):
# 	pass
#
# class DataLossError(AbstractError):
# 	pass
#
# class UnknownError(AbstractError):
# 	pass




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/command/v1/tool_commands.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/command/v1/tool_commands.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+olvid/daemon/command/v1/tool_commands.proto\x12\x17olvid.daemon.command.v1\"\r\n\x0bPingRequest\"\x0e\n\x0cPingResponse\"\x16\n\x14\x44\x61\x65monVersionRequest\"1\n\x15\x44\x61\x65monVersionResponse\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\"\x1b\n\x19\x41uthenticationTestRequest\"\x1c\n\x1a\x41uthenticationTestResponse\" \n\x1e\x41uthenticationAdminTestRequest\"!\n\x1f\x41uthenticationAdminTestResponseB\xc0\x01\n\x1b\x63om.olvid.daemon.command.v1B\x11ToolCommandsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODC\xaa\x02\x17Olvid.Daemon.Command.V1\xca\x02\x17Olvid\\Daemon\\Command\\V1\xe2\x02#Olvid\\Daemon\\Command\\V1\\GPBMetadata\xea\x02\x1aOlvid::Daemon::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.command.v1.tool_commands_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.olvid.daemon.command.v1B\021ToolCommandsProtoP\001Z\017olvid.io/daemon\242\002\003ODC\252\002\027Olvid.Daemon.Command.V1\312\002\027Olvid\\Daemon\\Command\\V1\342\002#Olvid\\Daemon\\Command\\V1\\GPBMetadata\352\002\032Olvid::Daemon::Command::V1'
  _globals['_PINGREQUEST']._serialized_start=72
  _globals['_PINGREQUEST']._serialized_end=85
  _globals['_PINGRESPONSE']._serialized_start=87
  _globals['_PINGRESPONSE']._serialized_end=101
  _globals['_DAEMONVERSIONREQUEST']._serialized_start=103
  _globals['_DAEMONVERSIONREQUEST']._serialized_end=125
  _globals['_DAEMONVERSIONRESPONSE']._serialized_start=127
  _globals['_DAEMONVERSIONRESPONSE']._serialized_end=176
  _globals['_AUTHENTICATIONTESTREQUEST']._serialized_start=178
  _globals['_AUTHENTICATIONTESTREQUEST']._serialized_end=205
  _globals['_AUTHENTICATIONTESTRESPONSE']._serialized_start=207
  _globals['_AUTHENTICATIONTESTRESPONSE']._serialized_end=235
  _globals['_AUTHENTICATIONADMINTESTREQUEST']._serialized_start=237
  _globals['_AUTHENTICATIONADMINTESTREQUEST']._serialized_end=269
  _globals['_AUTHENTICATIONADMINTESTRESPONSE']._serialized_start=271
  _globals['_AUTHENTICATIONADMINTESTRESPONSE']._serialized_end=304
# @@protoc_insertion_point(module_scope)
